==> reakit-0.14.5.tgz: package/es/Grid.js <==
import PropTypes__default from 'prop-types';
import { prop } from 'styled-tools';
import { a as bool, b as value } from './chunk-254efadd.js';
import styled from './styled.js';
import as from './as.js';
import Base from './Base.js';
import './chunk-a7ce379e.js';
import 'styled-components';
import './chunk-fb907809.js';
import '@emotion/is-prop-valid';
import 'react';

var Grid = styled(Base).withConfig({
  displayName: "Grid"
})(["display:grid;&&&{", " ", " ", " ", " ", " ", " ", " ", "}", ";"], bool("grid-auto-flow", ["row", "column", "dense"]), value("grid-gap", "gap"), value("grid-template", "template"), value("grid-template-areas", "areas"), value("grid-template-columns", "columns"), value("grid-template-rows", "rows"), value("grid-auto-columns", "autoColumns"), value("grid-auto-rows", "autoRows"), prop("theme.Grid"));
var valueType = PropTypes__default.oneOfType([PropTypes__default.string, PropTypes__default.number]);
Grid.propTypes = {
  row: PropTypes__default.bool,
  column: PropTypes__default.bool,
  dense: PropTypes__default.bool,
  gap: valueType,
  template: valueType,
  areas: valueType,
  columns: valueType,
  rows: valueType,
  autoColumns: valueType,
  autoRows: valueType
};
var Grid$1 = as("div")(Grid);

var GridItem = styled(Base).withConfig({
  displayName: "GridItem"
})(["&&&{", ";", ";", ";", ";", ";", ";", ";}", ";"], value("grid-area", "area"), value("grid-column", "column"), value("grid-row", "row"), value("grid-column-start", "columnStart"), value("grid-column-end", "columnEnd"), value("grid-row-start", "rowStart"), value("grid-row-end", "rowEnd"), prop("theme.GridItem"));
var valueType$1 = PropTypes__default.oneOfType([PropTypes__default.string, PropTypes__default.number]);
GridItem.propTypes = {
  area: valueType$1,
  column: valueType$1,
  row: valueType$1,
  columnStart: valueType$1,
  columnEnd: valueType$1,
  rowStart: valueType$1,
  rowEnd: valueType$1
};
var GridItem$1 = as("div")(GridItem);

Grid$1.Item = GridItem$1;

export default Grid$1;

==> reakit-0.14.6.tgz: package/es/Grid.js <==
import PropTypes__default from 'prop-types';
import { prop } from 'styled-tools';
import { a as bool, b as value } from './chunk-254efadd.js';
import styled from './styled.js';
import as from './as.js';
import Base from './Base.js';
import './chunk-a7ce379e.js';
import 'styled-components';
import './chunk-fb907809.js';
import '@emotion/is-prop-valid';
import 'react';
import 'hoist-non-react-statics';

var Grid = styled(Base).withConfig({
  displayName: "Grid",
  componentId: "sc-119pk16-0"
})(["display:grid;&&&{", " ", " ", " ", " ", " ", " ", " ", "}", ";"], bool("grid-auto-flow", ["row", "column", "dense"]), value("grid-gap", "gap"), value("grid-template", "template"), value("grid-template-areas", "areas"), value("grid-template-columns", "columns"), value("grid-template-rows", "rows"), value("grid-auto-columns", "autoColumns"), value("grid-auto-rows", "autoRows"), prop("theme.Grid"));
var valueType = PropTypes__default.oneOfType([PropTypes__default.string, PropTypes__default.number]);
Grid.propTypes = {
  row: PropTypes__default.bool,
  column: PropTypes__default.bool,
  dense: PropTypes__default.bool,
  gap: valueType,
  template: valueType,
  areas: valueType,
  columns: valueType,
  rows: valueType,
  autoColumns: valueType,
  autoRows: valueType
};
var Grid$1 = as("div")(Grid);

var GridItem = styled(Base).withConfig({
  displayName: "GridItem",
  componentId: "sc-30l0l5-0"
})(["&&&{", ";", ";", ";", ";", ";", ";", ";}", ";"], value("grid-area", "area"), value("grid-column", "column"), value("grid-row", "row"), value("grid-column-start", "columnStart"), value("grid-column-end", "columnEnd"), value("grid-row-start", "rowStart"), value("grid-row-end", "rowEnd"), prop("theme.GridItem"));
var valueType$1 = PropTypes__default.oneOfType([PropTypes__default.string, PropTypes__default.number]);
GridItem.propTypes = {
  area: valueType$1,
  column: valueType$1,
  row: valueType$1,
  columnStart: valueType$1,
  columnEnd: valueType$1,
  rowStart: valueType$1,
  rowEnd: valueType$1
};
var GridItem$1 = as("div")(GridItem);

Grid$1.Item = GridItem$1;

export default Grid$1;
